import { usePathname } from "next/navigation";
import { PropsWithChildren } from "react";
import { motion } from "framer-motion";
import { MainBlock } from "@/styles";

const transitionVariants = {
    initial: {
        scale: 0.8,
        opacity: 0
    },
    animate: {
        scale: 1,
        opacity: 1
    },
    exit: {
        scale: 1.2,
        opacity: 0
    }
};

const pageTransition = {
    type: "spring",
    ease: "anticipate",
    duration: 0.5
};

export default function Transitioned({ children }: PropsWithChildren) {
    const pathName = usePathname();

    return <motion.div
        key={pathName}
        variants={transitionVariants}
        transition={pageTransition}
        initial="initial"
        animate="animate"
        exit="exit"
    >
        <MainBlock>
            {children}
        </MainBlock>
    </motion.div>;
}